package com.dgtis.data.service.service.impl;

import java.util.List;

import com.dgtis.common.core.text.Convert;
import com.dgtis.data.service.domain.InsuranceArrangement;
import com.dgtis.data.service.mapper.InsuranceArrangementMapper;
import com.dgtis.data.service.service.IInsuranceArrangementService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 保单Service业务层处理
 * 
 * @author dgtly
 * @date 2021-01-20
 */
@Service
public class InsuranceArrangementServiceImpl implements IInsuranceArrangementService
{
    @Autowired
    private InsuranceArrangementMapper insuranceArrangementMapper;

    /**
     * 查询保单
     * 
     * @param iaid 保单ID
     * @return 保单
     */
    @Override
    public InsuranceArrangement selectInsuranceArrangementById(String iaid)
    {
        return insuranceArrangementMapper.selectInsuranceArrangementById(iaid);
    }

    /**
     * 查询保单列表
     * 
     * @param insuranceArrangement 保单
     * @return 保单
     */
    @Override
    public List<InsuranceArrangement> selectInsuranceArrangementList(InsuranceArrangement insuranceArrangement)
    {
        return insuranceArrangementMapper.selectInsuranceArrangementList(insuranceArrangement);
    }

    /**
     * 新增保单
     * 
     * @param insuranceArrangement 保单
     * @return 结果
     */
    @Override
    public int insertInsuranceArrangement(InsuranceArrangement insuranceArrangement)
    {
        return insuranceArrangementMapper.insertInsuranceArrangement(insuranceArrangement);
    }

    /**
     * 修改保单
     * 
     * @param insuranceArrangement 保单
     * @return 结果
     */
    @Override
    public int updateInsuranceArrangement(InsuranceArrangement insuranceArrangement)
    {
        return insuranceArrangementMapper.updateInsuranceArrangement(insuranceArrangement);
    }

    /**
     * 删除保单对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteInsuranceArrangementByIds(String ids)
    {
        return insuranceArrangementMapper.deleteInsuranceArrangementByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除保单信息
     * 
     * @param iaid 保单ID
     * @return 结果
     */
    @Override
    public int deleteInsuranceArrangementById(String iaid)
    {
        return insuranceArrangementMapper.deleteInsuranceArrangementById(iaid);
    }

    @Override
    public int count()
    {
        return insuranceArrangementMapper.count();
    }
}
